# Creating Fact Sheets
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/creating-fact-sheets#introduction)
  * [Creating a Fact Sheet in the Inventory](https://help.sap.com/docs/leanix/ea/creating-fact-sheets#creating-a-fact-sheet-in-the-inventory)
  * [Fact Sheet Naming Convention](https://help.sap.com/docs/leanix/ea/creating-fact-sheets#fact-sheet-naming-convention)
  * [Cloning a Fact Sheet](https://help.sap.com/docs/leanix/ea/creating-fact-sheets#cloning-a-fact-sheet)


Learn how to create fact sheets in the inventory. This guide also covers fact sheet naming conventions and cloning fact sheets.
